@@ -16,15 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: power-management.c,v 1.6 2005/03/20 10:20:55 kmaraas Exp $
+ $Id: power-management.c,v 1.8 2005/07/04 07:15:40 ryanl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <stdio.h>
-
 #include <sys/file.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
@@ -39,10 +37,8 @@
 #include <time.h>
 #include <unistd.h>
 
-#include <panel-applet.h>
-#include <panel-applet-gconf.h>
-
 #include "battstat.h"
+#include "battstat-hal.h"
 
 #define ERR_ACPID _("Can't access ACPI events in /var/run/acpid.socket! "    \
                     "Make sure the ACPI subsystem is working and "           \
@@ -59,8 +55,15 @@
 #define ERR_NO_SUPPORT _("Your platform is not supported!  The battery\n"   \
                          "monitor applet will not work on your system.\n")
 
+#define ERR_FREEBSD_ACPI _("There was an error reading information from "   \
+                           "the ACPI subsystem.  Check to make sure the "   \
+                           "ACPI subsystem is properly loaded.")
+
 static const char *apm_readinfo (BatteryStatus *status);
 static int pm_initialised;
+#ifdef HAVE_HAL
+static int using_hal;
+#endif
 
 /*
  * What follows is a series of platform-specific apm_readinfo functions
@@ -73,45 +76,157 @@ static int pm_initialised;
  * the problem might be.  This error message is not to be freed.
  */
 
-#ifdef __FreeBSD__
+
+/* Uncomment the following to enable a 'testing' backend.  When you add the
+   applet to the panel a window will appear that allows you to manually
+   change the battery status values for testing purposes.
+
+   NB: Be sure to unset this before committing!!
+ */
+
+/* #define BATTSTAT_TESTING_BACKEND */
+#ifdef BATTSTAT_TESTING_BACKEND
+
+#include <gtk/gtk.h>
+
+BatteryStatus test_status;
+
+static void
+test_update_boolean( GtkToggleButton *button, gboolean *value )
+{
+  *value = gtk_toggle_button_get_active( button );
+}
+
+static void
+test_update_integer( GtkSpinButton *spin, gint *value )
+{
+  *value = gtk_spin_button_get_value_as_int( spin );
+}
+
+static void
+initialise_test( void )
+{
+  GtkWidget *w;
+  GtkBox *box;
+
+  test_status.percent = 50;
+  test_status.minutes = 180;
+  test_status.present = TRUE;
+  test_status.on_ac_power = FALSE;
+  test_status.charging = FALSE;
+
+  box = GTK_BOX( gtk_vbox_new( 5, FALSE ) );
+
+  gtk_box_pack_start_defaults( box, gtk_label_new( "percent" ) );
+  w = gtk_spin_button_new_with_range( -1.0, 100.0, 1 );
+  gtk_spin_button_set_value( GTK_SPIN_BUTTON( w ), 50.0 );
+  g_signal_connect( G_OBJECT( w ), "value-changed",
+                    G_CALLBACK( test_update_integer ), &test_status.percent );
+  gtk_box_pack_start_defaults( box, w );
+
+  gtk_box_pack_start_defaults( box, gtk_label_new( "minutes" ) );
+  w = gtk_spin_button_new_with_range( -1.0, 1000.0, 1 );
+  gtk_spin_button_set_value( GTK_SPIN_BUTTON( w ), 180.0 );
+  g_signal_connect( G_OBJECT( w ), "value-changed",
+                    G_CALLBACK( test_update_integer ), &test_status.minutes );
+  gtk_box_pack_start_defaults( box, w );
+
+
+  w = gtk_toggle_button_new_with_label( "on_ac_power" );
+  g_signal_connect( G_OBJECT( w ), "toggled",
+                    G_CALLBACK( test_update_boolean ),
+                    &test_status.on_ac_power );
+  gtk_box_pack_start_defaults( box, w );
+
+  w = gtk_toggle_button_new_with_label( "charging" );
+  g_signal_connect( G_OBJECT( w ), "toggled",
+                    G_CALLBACK( test_update_boolean ), &test_status.charging );
+  gtk_box_pack_start_defaults( box, w );
+
+  w = gtk_toggle_button_new_with_label( "present" );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( w ), TRUE );
+  g_signal_connect( G_OBJECT( w ), "toggled",
+                    G_CALLBACK( test_update_boolean ), &test_status.present );
+  gtk_box_pack_start_defaults( box, w );
+
+  w = gtk_window_new( GTK_WINDOW_TOPLEVEL );
+  gtk_container_add( GTK_CONTAINER( w ), GTK_WIDGET( box ) );
+  gtk_widget_show_all( w );
+}
+
+static const char *
+apm_readinfo (BatteryStatus *status)
+{
+  static int test_initialised;
+
+  if( !test_initialised )
+    initialise_test();
+
+  test_initialised = 1;
+  *status = test_status;
+
+  return NULL;
+}
+
+#undef __linux__
+#undef HAVE_HAL
+
+#elif __FreeBSD__
 
 #include <machine/apm_bios.h>
+#include "acpi-freebsd.h"
+
+static struct acpi_info acpiinfo;
+static gboolean using_acpi;
+static int acpi_count;
+static struct apm_info apminfo;
 
 #define APMDEVICE "/dev/apm"
 
 static const char *
 apm_readinfo (BatteryStatus *status)
 {
-  /* This is how I read the information from the APM subsystem under
-     FreeBSD.  Each time this functions is called (once every second)
-     the APM device is opened, read from and then closed.
-  */
-  struct apm_info apminfo;
   int fd;
 
   if (DEBUG) g_print("apm_readinfo() (FreeBSD)\n");
 
-  fd = open(APMDEVICE, O_RDONLY);
-  if (fd == -1)
-  {
-    pm_initialised = 0;
-    return ERR_OPEN_APMDEV;
+  if (using_acpi) {
+    if (acpi_count <= 0) {
+      acpi_count = 30;
+      acpi_process_event(&acpiinfo);
+      if (acpi_freebsd_read(&apminfo, &acpiinfo) == FALSE)
+        return ERR_FREEBSD_ACPI;
+    }
+    acpi_count--;
   }
+  else
+  {
+    /* This is how I read the information from the APM subsystem under
+       FreeBSD.  Each time this functions is called (once every second)
+       the APM device is opened, read from and then closed.
+    */
+    fd = open(APMDEVICE, O_RDONLY);
+    if (fd == -1) {
+      return ERR_OPEN_APMDEV;
+    }
 
-  if (ioctl(fd, APMIO_GETINFO, &apminfo) == -1)
-    err(1, "ioctl(APMIO_GETINFO)");
+    if (ioctl(fd, APMIO_GETINFO, &apminfo) == -1)
+      err(1, "ioctl(APMIO_GETINFO)");
 
-  close(fd);
+    close(fd);
 
-  if(apminfo.ai_status == 0)
-    return ERR_APM_E;
+    if(apminfo.ai_status == 0)
+      return ERR_APM_E;
+  }
 
   status->present = TRUE;
   status->on_ac_power = apminfo.ai_acline ? 1 : 0;
-  status->state = apminfo.ai_batt_stat;
   status->percent = apminfo.ai_batt_life;
-  status->charging = (status->state == 3) ? TRUE : FALSE;
-  status->minutes = apminfo.ai_batt_time;
+  status->charging = (apminfo.ai_batt_stat) ? TRUE : FALSE;
+  if (using_acpi)
+    status->minutes = apminfo.ai_batt_time;
+  else
+    status->minutes = (int) (apminfo.ai_batt_time/60.0);
 
   return NULL;
 }
@@ -150,9 +265,8 @@ apm_readinfo (BatteryStatus *status)
 
   status->present = TRUE;
   status->on_ac_power = apminfo.ac_state ? 1 : 0;
-  status->state = apminfo.battery_state;
   status->percent = apminfo.battery_life;
-  status->charging = (status->state == 3) ? TRUE : FALSE;
+  status->charging = (apminfo.battery_state == 3) ? TRUE : FALSE;
   status->minutes = apminfo.minutes_left;
 
   return NULL;
@@ -221,7 +335,6 @@ apm_readinfo (BatteryStatus *status)
 
   status->present = TRUE;
   status->on_ac_power = apminfo.ac_line_status ? 1 : 0;
-  status->state = apminfo.battery_status;
   status->percent = (guint) apminfo.battery_percentage;
   status->charging = (apminfo.battery_flags & 0x8) ? TRUE : FALSE;
   status->minutes = apminfo.battery_time;
@@ -236,7 +349,6 @@ apm_readinfo (BatteryStatus *status)
 {
   status->present = FALSE;
   status->on_ac_power = 1;
-  status->state = BATTERY_HIGH;
   status->percent = 100;
   status->charging = FALSE;
   status->minutes = 0;
@@ -268,7 +380,6 @@ power_management_getinfo( BatteryStatus *status )
   if( !pm_initialised )
   {
     status->on_ac_power = TRUE;
-    status->state = BATTERY_CRITICAL;
     status->minutes = -1;
     status->percent = 0;
     status->charging = FALSE;
@@ -277,12 +388,15 @@ power_management_getinfo( BatteryStatus *status )
     return NULL;
   }
 
-  retval = apm_readinfo( status );
-
-  if(status->state > 3) {
-    status->state = 0;
-    status->present = FALSE;
+#ifdef HAVE_HAL
+  if( using_hal )
+  {
+    battstat_hal_get_battery_info( status );
+    return NULL;
   }
+#endif
+
+  retval = apm_readinfo( status );
 
   if(status->percent == (guint)-1) {
     status->percent = 0;
@@ -314,6 +428,22 @@ power_management_getinfo( BatteryStatus *status )
 const char *
 power_management_initialise( void )
 {
+#ifdef HAVE_HAL
+  char *err;
+
+  err = battstat_hal_initialise();
+
+  if( err == NULL ) /* HAL is up */
+  {
+    pm_initialised = 1;
+    using_hal = TRUE;
+    return NULL;
+  }
+  else
+    /* fallback to legacy methods */
+    g_free( err );
+#endif
+    
 #ifdef __linux__
   struct stat statbuf;
 
@@ -339,6 +469,13 @@ power_management_initialise( void )
         G_IO_IN | G_IO_ERR | G_IO_HUP,
         acpi_callback, NULL);
   }
+#elif defined(__FreeBSD__)
+  if (acpi_freebsd_init(&acpiinfo)) {
+    using_acpi = TRUE;
+    acpi_count = 0;
+  }
+  else
+    using_acpi = FALSE;
 #endif
   pm_initialised = 1;
 
@@ -353,6 +490,15 @@ power_management_initialise( void )
 void
 power_management_cleanup( void )
 {
+#ifdef HAVE_HAL
+  if( using_hal )
+  {
+    battstat_hal_cleanup();
+    pm_initialised = 1;
+    return;
+  }
+#endif
+
 #ifdef __linux__
   if (using_acpi)
   {
@@ -361,6 +507,10 @@ power_management_cleanup( void )
      acpiwatch = 0;
      acpi_linux_cleanup(&acpiinfo);
   }
+#elif defined(__FreeBSD__)
+  if (using_acpi) {
+    acpi_freebsd_cleanup(&acpiinfo);
+  }
 #endif
 
   pm_initialised = 0;
