@@ -246,8 +246,13 @@ phelp_cb (GtkDialog *dialog)
 		gtk_window_get_screen (GTK_WINDOW (dialog)),
 		&error);
 
-	if (error) { /* FIXME: the user needs to see this */
-		g_warning ("help error: %s\n", error->message);
+	if (error) {
+		GtkWidget *error_dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+								  _("There was an error displaying help: %s"), error->message);
+		g_signal_connect (G_OBJECT (error_dialog), "response", G_CALLBACK (gtk_widget_destroy) , NULL);
+		gtk_window_set_resizable (GTK_WINDOW (error_dialog), FALSE);
+		gtk_window_set_screen (GTK_WINDOW (error_dialog), gtk_widget_get_screen (GTK_WIDGET (dialog)));
+		gtk_widget_show (error_dialog);
 		g_error_free (error);
 		error = NULL;
 	}
