@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.9 2002/01/30 03:25:30 kevinv Exp $ */
+/* $Id: main.c,v 1.16 2005/06/09 08:42:59 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -10,9 +10,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
 #  include <config.h>
-#endif
 
 #include <gnome.h>
 #include <panel-applet.h>
@@ -23,7 +21,7 @@
 #include "gweather-applet.h"
 
 
-gboolean
+static gboolean
 gweather_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
 	GWeatherApplet *gw_applet;
@@ -33,11 +31,10 @@ gweather_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	gw_applet = g_new0(GWeatherApplet, 1);   
 	
 	gw_applet->applet = applet;
-
+	gw_applet->gweather_info = NULL;
     	gweather_applet_create(gw_applet);
 
     	gweather_pref_load(gw_applet);
-    	gweather_info_load("test_path", gw_applet);
     
     	gweather_update(gw_applet);
 
@@ -57,7 +54,8 @@ gweather_applet_factory(PanelApplet *applet,
 }
 
 PANEL_APPLET_BONOBO_FACTORY("OAFIID:GNOME_GWeatherApplet_Factory",
-			"GWeather Applet Factory",
+			PANEL_TYPE_APPLET,
+			"gweather",
 			"0",
 			gweather_applet_factory,
 			NULL);
